@@ -19,8 +19,13 @@ import (
 )
 
 func TestGitLabReleaseURLTemplate(t *testing.T) {
+	repo := config.Repo{
+		Owner: "owner",
+		Name:  "name",
+	}
 	tests := []struct {
 		name            string
+		repo            config.Repo
 		downloadURL     string
 		wantDownloadURL string
 		wantErr         bool
@@ -28,16 +33,24 @@ func TestGitLabReleaseURLTemplate(t *testing.T) {
 		{
 			name:            "default_download_url",
 			downloadURL:     DefaultGitLabDownloadURL,
+			repo:            repo,
 			wantDownloadURL: "https://gitlab.com/owner/name/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
 		},
+		{
+			name:            "default_download_url_no_owner",
+			downloadURL:     DefaultGitLabDownloadURL,
+			repo:            config.Repo{Name: "name"},
+			wantDownloadURL: "https://gitlab.com/name/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
+		},
 		{
 			name:            "download_url_template",
+			repo:            repo,
 			downloadURL:     "{{ .Env.GORELEASER_TEST_GITLAB_URLS_DOWNLOAD }}",
 			wantDownloadURL: "https://gitlab.mycompany.com/owner/name/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
 		},
 		{
 			name:        "download_url_template_invalid_value",
-			downloadURL: "{{ .Env.GORELEASER_NOT_EXISTS }}",
+			downloadURL: "{{ .Eenv.GORELEASER_NOT_EXISTS }}",
 			wantErr:     true,
 		},
 		{
@@ -45,6 +58,11 @@ func TestGitLabReleaseURLTemplate(t *testing.T) {
 			downloadURL: "{{.dddddddddd",
 			wantErr:     true,
 		},
+		{
+			name:            "download_url_string",
+			downloadURL:     "https://gitlab.mycompany.com",
+			wantDownloadURL: "https://gitlab.mycompany.com/",
+		},
 	}
 
 	for _, tt := range tests {
@@ -56,10 +74,7 @@ func TestGitLabReleaseURLTemplate(t *testing.T) {
 				Download: tt.downloadURL,
 			},
 			Release: config.Release{
-				GitLab: config.Repo{
-					Owner: "owner",
-					Name:  "name",
-				},
+				GitLab: tt.repo,
 			},
 		})
 		client, err := NewGitLab(ctx, ctx.Token)
@@ -323,3 +338,83 @@ func TestGitLabCreateReleaseUnkownHTTPError(t *testing.T) {
 	require.Error(t, err)
 	require.Equal(t, 2, totalRequests)
 }
+
+func TestGitlabGetDefaultBranch(t *testing.T) {
+	totalRequests := 0
+	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		totalRequests++
+		defer r.Body.Close()
+
+		// Assume the request to create a branch was good
+		w.WriteHeader(http.StatusOK)
+		fmt.Fprint(w, "{}")
+	}))
+	defer srv.Close()
+
+	ctx := context.New(config.Project{
+		GitLabURLs: config.GitLabURLs{
+			API: srv.URL,
+		},
+	})
+	client, err := NewGitLab(ctx, "test-token")
+	require.NoError(t, err)
+	repo := Repo{
+		Owner:  "someone",
+		Name:   "something",
+		Branch: "somebranch",
+	}
+
+	_, err = client.GetDefaultBranch(ctx, repo)
+	require.NoError(t, err)
+	require.Equal(t, 2, totalRequests)
+}
+
+func TestGitlabGetDefaultBranchErr(t *testing.T) {
+	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		defer r.Body.Close()
+
+		// Assume the request to create a branch was good
+		w.WriteHeader(http.StatusNotImplemented)
+		fmt.Fprint(w, "{}")
+	}))
+	defer srv.Close()
+
+	ctx := context.New(config.Project{
+		GitLabURLs: config.GitLabURLs{
+			API: srv.URL,
+		},
+	})
+	client, err := NewGitLab(ctx, "test-token")
+	require.NoError(t, err)
+	repo := Repo{
+		Owner:  "someone",
+		Name:   "something",
+		Branch: "somebranch",
+	}
+
+	_, err = client.GetDefaultBranch(ctx, repo)
+	require.Error(t, err)
+}
+
+func TestGitlabChangelog(t *testing.T) {
+	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		defer r.Body.Close()
+	}))
+	defer srv.Close()
+
+	ctx := context.New(config.Project{
+		GitLabURLs: config.GitLabURLs{
+			API: srv.URL,
+		},
+	})
+	client, err := NewGitLab(ctx, "test-token")
+	require.NoError(t, err)
+	repo := Repo{
+		Owner:  "someone",
+		Name:   "something",
+		Branch: "somebranch",
+	}
+
+	_, err = client.Changelog(ctx, repo, "v1.0.0", "v1.1.0")
+	require.EqualError(t, err, ErrNotImplemented.Error())
+}
