@@ -6,6 +6,7 @@ import (
 	"net/url"
 	"strings"
 
+	"github.com/apex/log"
 	"github.com/goreleaser/goreleaser/pkg/config"
 )
 
@@ -18,6 +19,7 @@ func ExtractRepoFromConfig() (result config.Repo, err error) {
 	if err != nil {
 		return result, fmt.Errorf("no remote configured to list refs from")
 	}
+	log.WithField("rawurl", out).Debugf("got git url")
 	return ExtractRepoFromURL(out)
 }
 
@@ -30,7 +32,17 @@ func ExtractRepoFromURL(rawurl string) (config.Repo, error) {
 	// on HTTP and HTTPS URLs it will remove the http(s): prefix,
 	// which is ok. On SSH URLs the whole user@server will be removed,
 	// which is required.
-	s = s[strings.LastIndex(s, ":")+1:]
+
+	// If the url contains more than 1 ':' character, assume we are doing an
+	// http URL with a username/password in it, and normalize the URL.
+	// Gitlab-CI uses this type of URL
+	if strings.Count(s, ":") == 1 {
+		s = s[strings.LastIndex(s, ":")+1:]
+	} else {
+		// Handle Gitlab-ci funky URLs in the form of:
+		// "https://gitlab-ci-token:SOME_TOKEN@gitlab.yourcompany.com/yourgroup/yourproject.git"
+		s = "//" + s[strings.LastIndex(s, "@")+1:]
+	}
 
 	// now we can parse it with net/url
 	u, err := url.Parse(s)
@@ -45,8 +57,10 @@ func ExtractRepoFromURL(rawurl string) (config.Repo, error) {
 	if len(ss) < 2 {
 		return config.Repo{}, fmt.Errorf("unsupported repository URL: %s", rawurl)
 	}
-	return config.Repo{
+	repo := config.Repo{
 		Owner: strings.Join(ss[:len(ss)-1], "/"),
 		Name:  ss[len(ss)-1],
-	}, nil
+	}
+	log.WithField("owner", repo.Owner).WithField("name", repo.Name).Debugf("parsed url")
+	return repo, nil
 }
