@@ -43,25 +43,39 @@ func TestSimpleName(t *testing.T) {
 var defaultTemplateData = templateData{
 	Desc:     "Some desc",
 	Homepage: "https://google.com",
-	MacOSAmd64: downloadable{
-		DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_x86_64.tar.gz",
-		SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c68",
+	LinuxPackages: []releasePackage{
+		{
+			DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Linux_x86_64.tar.gz",
+			SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+			OS:          "linux",
+			Arch:        "amd64",
+		},
+		{
+			DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Arm6.tar.gz",
+			SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+			OS:          "linux",
+			Arch:        "arm",
+		},
+		{
+			DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Arm64.tar.gz",
+			SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+			OS:          "linux",
+			Arch:        "arm64",
+		},
 	},
-	MacOSArm64: downloadable{
-		DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_arm64.tar.gz",
-		SHA256:      "1633f61598ab0791e213135923624eb342196b349490sadasdsadsadasdasdsd",
-	},
-	LinuxAmd64: downloadable{
-		DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Linux_x86_64.tar.gz",
-		SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
-	},
-	LinuxArm: downloadable{
-		DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Arm6.tar.gz",
-		SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
-	},
-	LinuxArm64: downloadable{
-		DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Arm64.tar.gz",
-		SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+	MacOSPackages: []releasePackage{
+		{
+			DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_x86_64.tar.gz",
+			SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c68",
+			OS:          "darwin",
+			Arch:        "amd64",
+		},
+		{
+			DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_arm64.tar.gz",
+			SHA256:      "1633f61598ab0791e213135923624eb342196b349490sadasdsadsadasdasdsd",
+			OS:          "darwin",
+			Arch:        "arm64",
+		},
 	},
 	Name:    "Test",
 	Version: "0.1.3",
@@ -98,8 +112,19 @@ func TestFullFormulae(t *testing.T) {
 
 func TestFullFormulaeLinuxOnly(t *testing.T) {
 	data := defaultTemplateData
-	data.MacOSAmd64 = downloadable{}
-	data.MacOSArm64 = downloadable{}
+	data.MacOSPackages = []releasePackage{}
+	data.Install = []string{`bin.install "test"`}
+	formulae, err := doBuildFormula(context.New(config.Project{
+		ProjectName: "foo",
+	}), data)
+	require.NoError(t, err)
+
+	golden.RequireEqualRb(t, []byte(formulae))
+}
+
+func TestFullFormulaeMacOSOnly(t *testing.T) {
+	data := defaultTemplateData
+	data.LinuxPackages = []releasePackage{}
 	data.Install = []string{`bin.install "test"`}
 	formulae, err := doBuildFormula(context.New(config.Project{
 		ProjectName: "foo",
@@ -129,6 +154,7 @@ func TestSplit(t *testing.T) {
 func TestFullPipe(t *testing.T) {
 	type testcase struct {
 		prepare              func(ctx *context.Context)
+		expectedRunError     string
 		expectedPublishError string
 	}
 	for name, tt := range map[string]testcase{
@@ -187,6 +213,30 @@ func TestFullPipe(t *testing.T) {
 			},
 			expectedPublishError: `template: tmpl:1: unexpected "}" in operand`,
 		},
+		"valid_tap_templates": {
+			prepare: func(ctx *context.Context) {
+				ctx.TokenType = context.TokenTypeGitHub
+				ctx.Env = map[string]string{
+					"FOO": "templated",
+				}
+				ctx.Config.Brews[0].Tap.Owner = "{{.Env.FOO}}"
+				ctx.Config.Brews[0].Tap.Name = "{{.Env.FOO}}"
+			},
+		},
+		"invalid_tap_name_template": {
+			prepare: func(ctx *context.Context) {
+				ctx.Config.Brews[0].Tap.Owner = "test"
+				ctx.Config.Brews[0].Tap.Name = "{{ .Asdsa }"
+			},
+			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
+		},
+		"invalid_tap_owner_template": {
+			prepare: func(ctx *context.Context) {
+				ctx.Config.Brews[0].Tap.Owner = "{{ .Asdsa }"
+				ctx.Config.Brews[0].Tap.Name = "test"
+			},
+			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
+		},
 	} {
 		t.Run(name, func(t *testing.T) {
 			folder := t.TempDir()
@@ -247,10 +297,15 @@ func TestFullPipe(t *testing.T) {
 			f, err := os.Create(path)
 			require.NoError(t, err)
 			require.NoError(t, f.Close())
-			client := &DummyClient{}
+			client := client.NewMock()
 			distFile := filepath.Join(folder, name+".rb")
 
-			require.NoError(t, runAll(ctx, client))
+			if tt.expectedRunError == "" {
+				require.NoError(t, runAll(ctx, client))
+			} else {
+				require.EqualError(t, runAll(ctx, client), tt.expectedRunError)
+				return
+			}
 			if tt.expectedPublishError != "" {
 				require.EqualError(t, publishAll(ctx, client), tt.expectedPublishError)
 				return
@@ -311,7 +366,7 @@ func TestRunPipeNameTemplate(t *testing.T) {
 	f, err := os.Create(path)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	client := &DummyClient{}
+	client := client.NewMock()
 	distFile := filepath.Join(folder, "foo_is_bar.rb")
 
 	require.NoError(t, runAll(ctx, client))
@@ -390,7 +445,7 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 
-	cli := &DummyClient{}
+	cli := client.NewMock()
 	require.NoError(t, runAll(ctx, cli))
 	require.EqualError(t, publishAll(ctx, cli), `brew.skip_upload is set`)
 	require.True(t, cli.CreatedFile)
@@ -511,7 +566,7 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 				require.NoError(t, f.Close())
 			}
 
-			client := &DummyClient{}
+			client := client.NewMock()
 			distFile := filepath.Join(folder, name+".rb")
 
 			require.NoError(t, runAll(ctx, client))
@@ -540,7 +595,7 @@ func TestRunPipeNoBuilds(t *testing.T) {
 			},
 		},
 	}
-	client := &DummyClient{}
+	client := client.NewMock()
 	require.Equal(t, ErrNoArchivesFound, runAll(ctx, client))
 	require.False(t, client.CreatedFile)
 }
@@ -684,7 +739,7 @@ func TestRunPipeMultipleArchivesSameOsBuild(t *testing.T) {
 				},
 			})
 		}
-		client := &DummyClient{}
+		client := client.NewMock()
 		require.Equal(t, test.expectedError, runAll(ctx, client))
 		require.False(t, client.CreatedFile)
 		// clean the artifacts for the next run
@@ -712,7 +767,7 @@ func TestRunPipeBinaryRelease(t *testing.T) {
 		Goarch: "amd64",
 		Type:   artifact.Binary,
 	})
-	client := &DummyClient{}
+	client := client.NewMock()
 	require.Equal(t, ErrNoArchivesFound, runAll(ctx, client))
 	require.False(t, client.CreatedFile)
 }
@@ -749,7 +804,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 			"Format": "tar.gz",
 		},
 	})
-	client := &DummyClient{}
+	client := client.NewMock()
 
 	assertNoPublish := func(t *testing.T) {
 		t.Helper()
@@ -801,46 +856,10 @@ func TestRunEmptyTokenType(t *testing.T) {
 			"Format": "tar.gz",
 		},
 	})
-	client := &DummyClient{}
+	client := client.NewMock()
 	require.NoError(t, runAll(ctx, client))
 }
 
-func TestRunTokenTypeNotImplementedForBrew(t *testing.T) {
-	folder := t.TempDir()
-	ctx := context.New(config.Project{
-		Dist:        folder,
-		ProjectName: "foo",
-		Release:     config.Release{},
-		Brews: []config.Homebrew{
-			{
-				Tap: config.RepoRef{
-					Owner: "test",
-					Name:  "test",
-				},
-			},
-		},
-	})
-	ctx.TokenType = context.TokenTypeGitea
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
-	path := filepath.Join(folder, "whatever.tar.gz")
-	f, err := os.Create(path)
-	require.NoError(t, err)
-	require.NoError(t, f.Close())
-	ctx.Artifacts.Add(&artifact.Artifact{
-		Name:   "bin",
-		Path:   path,
-		Goos:   "darwin",
-		Goarch: "amd64",
-		Type:   artifact.UploadableArchive,
-		Extra: map[string]interface{}{
-			"ID":     "foo",
-			"Format": "tar.gz",
-		},
-	})
-	client := &DummyClient{NotImplemented: true}
-	require.EqualError(t, runAll(ctx, client), `token type "gitea" not implemented for brew pipe`)
-}
-
 func TestDefault(t *testing.T) {
 	testlib.Mktmp(t)
 
@@ -886,38 +905,6 @@ func TestGHFolder(t *testing.T) {
 	require.Equal(t, "fooo/bar.rb", buildFormulaPath("fooo", "bar.rb"))
 }
 
-type DummyClient struct {
-	CreatedFile    bool
-	Content        string
-	NotImplemented bool
-}
-
-func (dc *DummyClient) CloseMilestone(ctx *context.Context, repo client.Repo, title string) error {
-	return nil
-}
-
-func (dc *DummyClient) CreateRelease(ctx *context.Context, body string) (releaseID string, err error) {
-	return
-}
-
-func (dc *DummyClient) ReleaseURLTemplate(ctx *context.Context) (string, error) {
-	if dc.NotImplemented {
-		return "", client.NotImplementedError{}
-	}
-
-	return "https://dummyhost/download/{{ .Tag }}/{{ .ArtifactName }}", nil
-}
-
-func (dc *DummyClient) CreateFile(ctx *context.Context, commitAuthor config.CommitAuthor, repo client.Repo, content []byte, path, msg string) (err error) {
-	dc.CreatedFile = true
-	dc.Content = string(content)
-	return
-}
-
-func (dc *DummyClient) Upload(ctx *context.Context, releaseID string, artifact *artifact.Artifact, file *os.File) (err error) {
-	return
-}
-
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
 		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
@@ -938,6 +925,6 @@ func TestRunSkipNoName(t *testing.T) {
 		Brews: []config.Homebrew{{}},
 	})
 
-	client := &DummyClient{}
+	client := client.NewMock()
 	testlib.AssertSkipped(t, runAll(ctx, client))
 }
