@@ -47,9 +47,10 @@ type Repo struct {
 // also require separate authentication
 // e.g. Homebrew Tap, Scoop bucket.
 type RepoRef struct {
-	Owner string `yaml:",omitempty"`
-	Name  string `yaml:",omitempty"`
-	Token string `yaml:",omitempty"`
+	Owner  string `yaml:",omitempty"`
+	Name   string `yaml:",omitempty"`
+	Token  string `yaml:",omitempty"`
+	Branch string `yaml:",omitempty"`
 }
 
 // HomebrewDependency represents Homebrew dependency.
@@ -88,6 +89,21 @@ func (r Repo) String() string {
 	return r.Owner + "/" + r.Name
 }
 
+// GoFish contains the gofish section.
+type GoFish struct {
+	Name                  string       `yaml:",omitempty"`
+	Rig                   RepoRef      `yaml:",omitempty"`
+	CommitAuthor          CommitAuthor `yaml:"commit_author,omitempty"`
+	CommitMessageTemplate string       `yaml:"commit_msg_template,omitempty"`
+	Description           string       `yaml:",omitempty"`
+	Homepage              string       `yaml:",omitempty"`
+	License               string       `yaml:",omitempty"`
+	SkipUpload            string       `yaml:"skip_upload,omitempty"`
+	URLTemplate           string       `yaml:"url_template,omitempty"`
+	IDs                   []string     `yaml:"ids,omitempty"`
+	Goarm                 string       `yaml:"goarm,omitempty"`
+}
+
 // Homebrew contains the brew section.
 type Homebrew struct {
 	Name                  string               `yaml:",omitempty"`
@@ -579,6 +595,7 @@ type Changelog struct {
 	Filters Filters `yaml:",omitempty"`
 	Sort    string  `yaml:",omitempty"`
 	Skip    bool    `yaml:",omitempty"` // TODO(caarlos0): rename to Disable to match other pipes
+	Use     string  `yaml:",omitempty"`
 }
 
 // EnvFiles holds paths to files that contains environment variables
@@ -648,6 +665,7 @@ type Project struct {
 	Release         Release          `yaml:",omitempty"`
 	Milestones      []Milestone      `yaml:",omitempty"`
 	Brews           []Homebrew       `yaml:",omitempty"`
+	Rigs            []GoFish         `yaml:",omitempty"`
 	Scoop           Scoop            `yaml:",omitempty"`
 	Builds          []Build          `yaml:",omitempty"`
 	Archives        []Archive        `yaml:",omitempty"`
@@ -691,12 +709,14 @@ type GoMod struct {
 }
 
 type Announce struct {
-	Twitter Twitter `yaml:"twitter,omitempty"`
-	Reddit  Reddit  `yaml:"reddit,omitempty"`
-	Slack   Slack   `yaml:"slack,omitempty"`
-	Discord Discord `yaml:"discord,omitempty"`
-	Teams   Teams   `yaml:"teams,omitempty"`
-	SMTP    SMTP    `yaml:"smtp,omitempty"`
+	Skip       string     `yaml:"skip,omitempty"`
+	Twitter    Twitter    `yaml:"twitter,omitempty"`
+	Reddit     Reddit     `yaml:"reddit,omitempty"`
+	Slack      Slack      `yaml:"slack,omitempty"`
+	Discord    Discord    `yaml:"discord,omitempty"`
+	Teams      Teams      `yaml:"teams,omitempty"`
+	SMTP       SMTP       `yaml:"smtp,omitempty"`
+	Mattermost Mattermost `yaml:"mattermost,omitempty"`
 }
 
 type Twitter struct {
@@ -738,6 +758,17 @@ type Teams struct {
 	IconURL         string `yaml:"icon_url,omitempty"`
 }
 
+type Mattermost struct {
+	Enabled         bool   `yaml:"enabled,omitempty"`
+	MessageTemplate string `yaml:"message_template,omitempty"`
+	TitleTemplate   string `yaml:"title_template,omitempty"`
+	Color           string `yaml:"color,omitempty"`
+	Channel         string `yaml:"channel,omitempty"`
+	Username        string `yaml:"username,omitempty"`
+	IconEmoji       string `yaml:"icon_emoji,omitempty"`
+	IconURL         string `yaml:"icon_url,omitempty"`
+}
+
 type SMTP struct {
 	Enabled            bool     `yaml:"enabled,omitempty"`
 	Host               string   `yaml:"host,omitempty"`
